==> openshift-enterprise-console-operator-container-v4.4.0-202005252114.tar.gz: openshift-enterprise-console-operator-container-v4.4.0-202005252114/pkg/api/api.go <==
package api

const (
	TargetNamespace    = "openshift-console"
	ConfigResourceName = "cluster"
)

// consts to maintain existing names of various sub-resources
const (
	ClusterOperatorName                 = "console"
	OpenShiftConsoleName                = "console"
	OpenShiftConsoleNamespace           = TargetNamespace
	OpenShiftConsoleOperatorNamespace   = "openshift-console-operator"
	OpenShiftConsoleOperator            = "console-operator"
	OpenShiftConsoleConfigMapName       = "console-config"
	OpenShiftConsolePublicConfigMapName = "console-public"
	ServiceCAConfigMapName              = "service-ca"
	DefaultIngressCertConfigMapName     = "default-ingress-cert"
	OpenShiftConsoleDeploymentName      = OpenShiftConsoleName
	OpenShiftConsoleServiceName         = OpenShiftConsoleName
	OpenShiftConsoleRouteName           = OpenShiftConsoleName
	OpenShiftConsoleDownloadsRouteName  = "downloads"
	OAuthClientName                     = OpenShiftConsoleName
	OpenShiftConfigManagedNamespace     = "openshift-config-managed"
	OpenShiftConfigNamespace            = "openshift-config"
	OpenShiftMonitoringConfigMapName    = "monitoring-shared-config"
	OpenShiftCustomLogoConfigMapName    = "custom-logo"
	TrustedCAConfigMapName              = "trusted-ca-bundle"
	TrustedCABundleKey                  = "ca-bundle.crt"
	TrustedCABundleMountDir             = "/etc/pki/ca-trust/extracted/pem"
	TrustedCABundleMountFile            = "tls-ca-bundle.pem"
	OCCLIDownloadsCustomResourceName    = "oc-cli-downloads"
	ODOCLIDownloadsCustomResourceName   = "odo-cli-downloads"
)

==> openshift-enterprise-console-operator-container-v4.6.0-202103060018.p0.tar.gz: openshift-enterprise-console-operator-container-v4.6.0-202103060018.p0/pkg/api/api.go <==
package api

const (
	TargetNamespace    = "openshift-console"
	ConfigResourceName = "cluster"
)

// consts to maintain existing names of various sub-resources
const (
	ClusterOperatorName                 = "console"
	OpenShiftConsoleName                = "console"
	OpenShiftConsoleNamespace           = TargetNamespace
	OpenShiftConsoleOperatorNamespace   = "openshift-console-operator"
	OpenShiftConsoleOperator            = "console-operator"
	OpenShiftConsoleConfigMapName       = "console-config"
	OpenShiftConsolePublicConfigMapName = "console-public"
	ServiceCAConfigMapName              = "service-ca"
	DefaultIngressCertConfigMapName     = "default-ingress-cert"
	OpenShiftConsoleDeploymentName      = OpenShiftConsoleName
	OpenShiftConsoleServiceName         = OpenShiftConsoleName
	OpenshiftConsoleRedirectServiceName = "console-redirect"
	OpenShiftConsoleRouteName           = OpenShiftConsoleName
	OpenshiftConsoleCustomRouteName     = "console-custom"
	OpenShiftConsoleDownloadsRouteName  = "downloads"
	OAuthClientName                     = OpenShiftConsoleName
	OpenShiftConfigManagedNamespace     = "openshift-config-managed"
	OpenShiftConfigNamespace            = "openshift-config"
	OpenShiftMonitoringConfigMapName    = "monitoring-shared-config"
	OpenShiftCustomLogoConfigMapName    = "custom-logo"
	TrustedCAConfigMapName              = "trusted-ca-bundle"
	TrustedCABundleKey                  = "ca-bundle.crt"
	TrustedCABundleMountDir             = "/etc/pki/ca-trust/extracted/pem"
	TrustedCABundleMountFile            = "tls-ca-bundle.pem"
	OCCLIDownloadsCustomResourceName    = "oc-cli-downloads"
	ODOCLIDownloadsCustomResourceName   = "odo-cli-downloads"

	ConsoleContainerPortName    = "https"
	ConsoleContainerPort        = 443
	ConsoleContainerTargetPort  = 8443
	RedirectContainerPortName   = "custom-route-redirect"
	RedirectContainerPort       = 8444
	RedirectContainerTargetPort = RedirectContainerPort
	ConsoleServingCertName      = "console-serving-cert"
)
